#ifndef HighlightStyleList_h
#define HighlightStyleList_h

// $Id: HighlightStyleList.h,v 1.6 2009/09/09 02:29:44 hpereira Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
  \file HighlightStyleList.h
  \brief List box for HighlightStyles
  \author Hugo Pereira
  \version $Revision: 1.6 $
  \date $Date: 2009/09/09 02:29:44 $
*/

#include <QPushButton>
#include <QGroupBox>

#include "Counter.h"
#include "HighlightStyleModel.h"

class TreeView;

//! List box for HighlightStyles
class HighlightStyleList: public QGroupBox, public Counter
{

  Q_OBJECT

  public:

  //! constructor
  HighlightStyleList( QWidget* parent = 0 );

  //! styles
  void setStyles( const HighlightStyle::Set& );

  //! styles
  HighlightStyle::Set styles( void );

  signals:

  //! emitted when list is modified
  void modified( void );

  private slots:

  //! update buttons enability
  void _updateButtons( void );

  //! edit selected style
  void _edit( void );

  //! remove selected style
  void _remove( void );

  //! add new style
  void _add( void );

  //! store selection
  void _storeSelection( void );

  //! restore selection
  void _restoreSelection( void );

  private:

  //! list
  TreeView* list_;

  //! model
  HighlightStyleModel model_;

  //! buttons
  QPushButton* edit_button_;

  //! buttons
  QPushButton* remove_button_;

};

#endif
