#ifndef TextMacroList_h
#define TextMacroList_h

// $Id: TextMacroList.h,v 1.3 2011/08/04 11:17:42 hpereira Exp $
/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* software; if not, write to the Free Software Foundation, Inc., 59 Temple
* Place, Suite 330, Boston, MA  02111-1307 USA
*
*
*******************************************************************************/

/*!
\file TextMacroList.h
\brief List box for TextMacros
\author Hugo Pereira
\version $Revision: 1.3 $
\date $Date: 2011/08/04 11:17:42 $
*/

#include <QPushButton>
#include <QGroupBox>

#include "Counter.h"
#include "TextMacroModel.h"
#include "DocumentClass.h"

class TreeView;

//! List box for TextMacros
class TextMacroList: public QGroupBox, public Counter
{
    
    Q_OBJECT
        
        public:
        
        //! constructor
        TextMacroList( QWidget* parent = 0 );
    
    //! macro
    void setMacros( const TextMacro::List& );
    
    //! Macro
    TextMacro::List macros( void );
    
    //! true when Macro are modified
    bool modified( void ) const
    { return modified_; }
    
    private slots:
    
    //! update buttons enability
    void _updateButtons( void );
    
    //! edit selected Pattern
    void _edit( void );
    
    //! remove selected Pattern
    void _remove( void );
    
    //! add new Pattern
    void _add( void );
    
    //! add new Pattern
    void _addSeparator( void );
    
    //! store selection
    void _storeSelection( void );
    
    //! restore selection
    void _restoreSelection( void );
    
    //! move up selected task
    void _up( void );
    
    //! move down selected task
    void _down( void );
    
    private:
    
    //! list
    TreeView* list_;
    
    //! model
    TextMacroModel model_;
    
    //! buttons
    QPushButton* editButton_;
    
    //! buttons
    QPushButton* removeButton_;
    
    //! buttons
    QPushButton* moveUpButton_;
    
    //! buttons
    QPushButton* moveDownButton_;
    
    //! modification state
    bool modified_;
    
};

#endif
